@@ -32,11 +32,15 @@ The best way to browse API documentation is on [Constructs Hub](https://construc
 
 A runner provider creates compute resources on-demand and uses [actions/runner](https://github.com/actions/runner) to start a runner.
 
-| Provider  | Time limit               | vCPUs                    | RAM                               | Storage                      | sudo | Docker |
-|-----------|--------------------------|--------------------------|-----------------------------------|------------------------------|------|--------|
-| CodeBuild | 8 hours (default 1 hour) | 2 (default), 4, 8, or 72 | 3gb (default), 7gb, 15gb or 145gb | 50gb to 824gb (default 64gb) | ✔    | ✔     |
-| Fargate   | Unlimited                | 0.25 to 4 (default 1)    | 512mb to 30gb (default 2gb)       | 20gb to 200gb (default 25gb) | ✔    | ❌    |
-| Lambda    | 15 minutes               | 1 to 6 (default 2)       | 128mb to 10gb (default 2gb)       | Up to 10gb (default 10gb)    | ❌    | ❌     |
+|                | CodeBuild                | Fargate       | Lambda        |
+|----------------|--------------------------|---------------|---------------|
+| **Time limit** | 8 hours                  | Unlimited     | 15 minutes    |
+| **vCPUs**      | 2, 4, 8, or 72           | 0.25 to 4     | 1 to 6        |
+| **RAM**        | 3gb, 7gb, 15gb, or 145gb | 512mb to 30gb | 128mb to 10gb |
+| **Storage**    | 50gb to 824gb            | 20gb to 200gb | Up to 10gb    |
+| **sudo**       | ✔                        | ✔             | ❌             |
+| **Docker**     | ✔                        | ❌             | ❌             |
+| **Spot**       | ❌                        | ✔             | ❌             |
 
 The best provider to use mostly depends on your current infrastructure. When in doubt, CodeBuild is always a good choice. Execution history and logs are easy to view, and it has no restrictive limits unless you need to run for more than 8 hours.
 
@@ -84,9 +88,11 @@ You can also create your own provider by implementing `IRunnerProvider`.
 9. Trigger a GitHub action that has a `self-hosted` label with `runs-on: [self-hosted, linux, codebuild]` or similar
 10. If the action is not successful, see [troubleshooting](#Troubleshooting)
 
+[![Demo](demo-thumbnail.jpg)](https://youtu.be/wlyv_3V8lIw)
+
 ## Customizing
 
-The default providers configured by [`GitHubRunners`](https://constructs.dev/packages/@cloudsnorkel/cdk-github-runners/v/0.0.11/api/GitHubRunners?lang=typescript) are useful for testing but probably not too much for actual production work. They run in the default VPC or no VPC and have no added IAM permissions. You would usually want to configure the providers yourself.
+The default providers configured by `GitHubRunners` are useful for testing but probably not too much for actual production work. They run in the default VPC or no VPC and have no added IAM permissions. You would usually want to configure the providers yourself.
 
 For example:
 
@@ -131,7 +137,6 @@ new GitHubRunners(
   'runners',
   {
     providers: [myProvider],
-    defaultProviderLabel: 'my-codebuild',
   }
 );
 
@@ -223,7 +228,6 @@ class GitHubRunners(
           'runners',
           {
             providers: [myProvider],
-            defaultProviderLabel: 'my-codebuild',
           }
        );
 
@@ -235,32 +239,19 @@ class GitHubRunners(
         scope: constructs.Construct,
         id: builtins.str,
         *,
-        default_provider_label: typing.Optional[builtins.str] = None,
         providers: typing.Optional[typing.Sequence["IRunnerProvider"]] = None,
     ) -> None:
         '''
         :param scope: -
         :param id: -
-        :param default_provider_label: (experimental) Label of default provider in case the workflow job doesn't specify any known label. A provider with that label must be configured. Default: 'codebuild'
         :param providers: (experimental) List of runner providers to use. At least one provider is required. Provider will be selected when its label matches the labels requested by the workflow job. Default: CodeBuild, Lambda and Fargate runners with all the defaults (no VPC or default account VPC)
 
         :stability: experimental
         '''
-        props = GitHubRunnersProps(
-            default_provider_label=default_provider_label, providers=providers
-        )
+        props = GitHubRunnersProps(providers=providers)
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="defaultProvider")
-    def default_provider(self) -> "IRunnerProvider":
-        '''(experimental) Default provider as set by {@link GitHubRunnersProps.defaultProviderLabel}.
-
-        :stability: experimental
-        '''
-        return typing.cast("IRunnerProvider", jsii.get(self, "defaultProvider"))
-
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="props")
     def props(self) -> "GitHubRunnersProps":
@@ -291,44 +282,24 @@ class GitHubRunners(
 @jsii.data_type(
     jsii_type="@cloudsnorkel/cdk-github-runners.GitHubRunnersProps",
     jsii_struct_bases=[],
-    name_mapping={
-        "default_provider_label": "defaultProviderLabel",
-        "providers": "providers",
-    },
+    name_mapping={"providers": "providers"},
 )
 class GitHubRunnersProps:
     def __init__(
         self,
         *,
-        default_provider_label: typing.Optional[builtins.str] = None,
         providers: typing.Optional[typing.Sequence["IRunnerProvider"]] = None,
     ) -> None:
         '''(experimental) Properties for GitHubRunners.
 
-        :param default_provider_label: (experimental) Label of default provider in case the workflow job doesn't specify any known label. A provider with that label must be configured. Default: 'codebuild'
         :param providers: (experimental) List of runner providers to use. At least one provider is required. Provider will be selected when its label matches the labels requested by the workflow job. Default: CodeBuild, Lambda and Fargate runners with all the defaults (no VPC or default account VPC)
 
         :stability: experimental
         '''
         self._values: typing.Dict[str, typing.Any] = {}
-        if default_provider_label is not None:
-            self._values["default_provider_label"] = default_provider_label
         if providers is not None:
             self._values["providers"] = providers
 
-    @builtins.property
-    def default_provider_label(self) -> typing.Optional[builtins.str]:
-        '''(experimental) Label of default provider in case the workflow job doesn't specify any known label.
-
-        A provider with that label must be configured.
-
-        :default: 'codebuild'
-
-        :stability: experimental
-        '''
-        result = self._values.get("default_provider_label")
-        return typing.cast(typing.Optional[builtins.str], result)
-
     @builtins.property
     def providers(self) -> typing.Optional[typing.List["IRunnerProvider"]]:
         '''(experimental) List of runner providers to use.
@@ -1265,6 +1236,7 @@ class FargateRunner(
         label: typing.Optional[builtins.str] = None,
         memory_limit_mib: typing.Optional[jsii.Number] = None,
         security_group: typing.Optional[aws_cdk.aws_ec2.ISecurityGroup] = None,
+        spot: typing.Optional[builtins.bool] = None,
         vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
         log_retention: typing.Optional[aws_cdk.aws_logs.RetentionDays] = None,
         runner_version: typing.Optional[RunnerVersion] = None,
@@ -1279,6 +1251,7 @@ class FargateRunner(
         :param label: (experimental) GitHub Actions label used for this provider. Default: 'fargate'
         :param memory_limit_mib: (experimental) The amount (in MiB) of memory used by the task. For tasks using the Fargate launch type, this field is required and you must use one of the following values, which determines your range of valid values for the cpu parameter: 512 (0.5 GB), 1024 (1 GB), 2048 (2 GB) - Available cpu values: 256 (.25 vCPU) 1024 (1 GB), 2048 (2 GB), 3072 (3 GB), 4096 (4 GB) - Available cpu values: 512 (.5 vCPU) 2048 (2 GB), 3072 (3 GB), 4096 (4 GB), 5120 (5 GB), 6144 (6 GB), 7168 (7 GB), 8192 (8 GB) - Available cpu values: 1024 (1 vCPU) Between 4096 (4 GB) and 16384 (16 GB) in increments of 1024 (1 GB) - Available cpu values: 2048 (2 vCPU) Between 8192 (8 GB) and 30720 (30 GB) in increments of 1024 (1 GB) - Available cpu values: 4096 (4 vCPU) Default: 2048
         :param security_group: (experimental) Security Group to assign to the task. Default: a new security group
+        :param spot: (experimental) Use Fargate spot capacity provider to save money. - Runners may fail to start due to missing capacity. - Runners might be stopped prematurely with spot pricing. Default: false
         :param vpc: (experimental) VPC to launch the runners in. Default: default account VPC
         :param log_retention: (experimental) The number of days log events are kept in CloudWatch Logs. When updating this property, unsetting it doesn't remove the log retention policy. To remove the retention policy, set the value to ``INFINITE``. Default: logs.RetentionDays.ONE_MONTH
         :param runner_version: (experimental) Version of GitHub Runners to install. Default: latest version available
@@ -1293,6 +1266,7 @@ class FargateRunner(
             label=label,
             memory_limit_mib=memory_limit_mib,
             security_group=security_group,
+            spot=spot,
             vpc=vpc,
             log_retention=log_retention,
             runner_version=runner_version,
@@ -1386,6 +1360,15 @@ class FargateRunner(
         '''
         return typing.cast(builtins.str, jsii.get(self, "label"))
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="spot")
+    def spot(self) -> builtins.bool:
+        '''(experimental) Use spot pricing for Fargate tasks.
+
+        :stability: experimental
+        '''
+        return typing.cast(builtins.bool, jsii.get(self, "spot"))
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="task")
     def task(self) -> aws_cdk.aws_ecs.FargateTaskDefinition:
@@ -1427,6 +1410,7 @@ class FargateRunner(
         "label": "label",
         "memory_limit_mib": "memoryLimitMiB",
         "security_group": "securityGroup",
+        "spot": "spot",
         "vpc": "vpc",
     },
 )
@@ -1443,6 +1427,7 @@ class FargateRunnerProps(RunnerProviderProps):
         label: typing.Optional[builtins.str] = None,
         memory_limit_mib: typing.Optional[jsii.Number] = None,
         security_group: typing.Optional[aws_cdk.aws_ec2.ISecurityGroup] = None,
+        spot: typing.Optional[builtins.bool] = None,
         vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
     ) -> None:
         '''(experimental) Properties for FargateRunner.
@@ -1456,6 +1441,7 @@ class FargateRunnerProps(RunnerProviderProps):
         :param label: (experimental) GitHub Actions label used for this provider. Default: 'fargate'
         :param memory_limit_mib: (experimental) The amount (in MiB) of memory used by the task. For tasks using the Fargate launch type, this field is required and you must use one of the following values, which determines your range of valid values for the cpu parameter: 512 (0.5 GB), 1024 (1 GB), 2048 (2 GB) - Available cpu values: 256 (.25 vCPU) 1024 (1 GB), 2048 (2 GB), 3072 (3 GB), 4096 (4 GB) - Available cpu values: 512 (.5 vCPU) 2048 (2 GB), 3072 (3 GB), 4096 (4 GB), 5120 (5 GB), 6144 (6 GB), 7168 (7 GB), 8192 (8 GB) - Available cpu values: 1024 (1 vCPU) Between 4096 (4 GB) and 16384 (16 GB) in increments of 1024 (1 GB) - Available cpu values: 2048 (2 vCPU) Between 8192 (8 GB) and 30720 (30 GB) in increments of 1024 (1 GB) - Available cpu values: 4096 (4 vCPU) Default: 2048
         :param security_group: (experimental) Security Group to assign to the task. Default: a new security group
+        :param spot: (experimental) Use Fargate spot capacity provider to save money. - Runners may fail to start due to missing capacity. - Runners might be stopped prematurely with spot pricing. Default: false
         :param vpc: (experimental) VPC to launch the runners in. Default: default account VPC
 
         :stability: experimental
@@ -1479,6 +1465,8 @@ class FargateRunnerProps(RunnerProviderProps):
             self._values["memory_limit_mib"] = memory_limit_mib
         if security_group is not None:
             self._values["security_group"] = security_group
+        if spot is not None:
+            self._values["spot"] = spot
         if vpc is not None:
             self._values["vpc"] = vpc
 
@@ -1618,6 +1606,20 @@ class FargateRunnerProps(RunnerProviderProps):
         result = self._values.get("security_group")
         return typing.cast(typing.Optional[aws_cdk.aws_ec2.ISecurityGroup], result)
 
+    @builtins.property
+    def spot(self) -> typing.Optional[builtins.bool]:
+        '''(experimental) Use Fargate spot capacity provider to save money.
+
+        - Runners may fail to start due to missing capacity.
+        - Runners might be stopped prematurely with spot pricing.
+
+        :default: false
+
+        :stability: experimental
+        '''
+        result = self._values.get("spot")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
     @builtins.property
     def vpc(self) -> typing.Optional[aws_cdk.aws_ec2.IVpc]:
         '''(experimental) VPC to launch the runners in.
